<?php
/**
 *  @file
 *  Admin form for comment_revisions
 */

/**
 * FAPI definition for the comment revisions settings form
 *
 * @ingroup forms
 * @see comment_revisions_admin_validate()
 * @see comment_revisions_admin_submit()
 */
function comment_revisions_admin() {
  $form['comment_revisions_max_user'] = array(
    '#type' => 'textfield',
    '#title' => t('Maximum number of user revisions'),
    '#description' => t('Maximum number of user revisions to keep. Older revisions are discarded when this limit is reached. (0 = no limit).'),
    '#default_value' => variable_get('comment_revisions_max_user', 5),
    '#size' => 2,
    '#maxlength' => 6,
    '#required' => TRUE,
  );
  $form['comment_revisions_max_admin'] = array(
    '#type' => 'textfield',
    '#title' => t('Maximum number of administrator revisions'),
    '#description' => t('Maximum number of administrator revisions to keep. Older revisions are discarded when this limit is reached. (0 = no limit).'),
    '#default_value' => variable_get('comment_revisions_max_admin', 0),
    '#size' => 2,
    '#maxlength' => 6,
    '#required' => TRUE,
  );
  $form['comment_revisions_enable_log_message_field'] = array(
    '#type' => 'checkbox',
    '#title' => t('Enable the log message field'),
    '#description' => t('Include a revision log message field on the comment form.'),
    '#default_value' => variable_get('comment_revisions_enable_log_message_field', TRUE),
  );
  return system_settings_form($form);
}

/**
 * Form validate for comment_revisions_admin.
 */
function comment_revisions_admin_validate($form, &$form_state) {
  if (!is_numeric($form_state['values']['comment_revisions_max_admin'])) {
    form_set_error('comment_revisions_max_admin', t('Maximum number of administrator revisions has to be a number.'));
  }
  if (!is_numeric($form_state['values']['comment_revisions_max_user'])) {
    form_set_error('comment_revisions_max_user', t('Maximum number of user revisions has to be a number.'));
  }

  if ($form_state['values']['comment_revisions_max_admin'] < 0) {
    form_set_error('comment_revisions_max_admin', t('Maximum number of administrator revisions can be no less than 0.'));
  }
  if ($form_state['values']['comment_revisions_max_user'] < 0) {
    form_set_error('comment_revisions_max_user', t('Maximum number of user revisions can be no less than 0.'));
  }
}

/**
 * Overview page callback
 */
function comment_revisions_overview($cid) {
  global $user;
  $creator = (!user_access('view comment revisions') && user_access('view own comment revisions')) ? $user->uid : FALSE;
  $revisions = _comment_revisions_for_comment($cid, $creator);
  $currentvid = _comment_revisions_get_current_revision($cid);
  $cmt = _comment_load($cid);
  $uid = $cmt->uid;
  $rows = array();

  foreach ($revisions as $revision) {
    $row = array();
    $operations = array();
    $revision_is_user = ($revision->createdby == $uid) ? ('<p class="revision_isusrrev">' . t('(user revision)') . '</p>') : '';
    $datelink = l(format_date($revision->createdon, 'small'), "node/{$revision->nid}/", $options = array('fragment' => "comment-{$revision->cid}"));
    $comment = '<h3 class="title">' . filter_xss($revision->subject) . '</h3>'
      . '<div class="submitted">' . t('!date by !username', array('!date' => $datelink, '!username' => theme('username', $revision))) . '</div>'
      . '<p class="comment">' . filter_xss($revision->comment) . '</p>';
    $tempar = array(
      'data' => $comment . $revision_is_user
      . (($revision->logmessage != '') ? '<p class="revision-log">(' . filter_xss($revision->logmessage) . ')</p>' : '')
    );
    if ($revision->vid == $currentvid) {
      $tempar['class'] = 'revision-current';
      $operations[] = array('data' => theme('placeholder', t('current revision')) . '<br />' . l(t('delete'), "commentrevision/$revision->vid/delete"), 'class' => 'revision-current', 'colspan' => 2);

    }
    else {
      $operations[] = l(t('revert'), "commentrevision/$revision->vid/revert") . '<br />' . l(t('delete'), "commentrevision/$revision->vid/delete");
    }

    $row[] = $tempar;
    $rows[] = array_merge($row, $operations);
  }

  $header = array(t('Revision'), array('data' => t('Operations'), 'colspan' => 2));
  /* create back link */
  $path = 'node/' . _comment_revisions_getnid($cid);
  $pathfragment = "comment-$cid";
  $attributes = array();
  $query = NULL;
  $output = '<p>' . l(t('Back to comment'), $path , $options = array('attributes' => $attributes, 'query' => $query, 'fragment' => $pathfragment)) . '</p>';
  $output .= theme('table', $header, $rows, array('id' => 'comment-revisions'));
  return $output;
}

/**
 * Confirm revert form.
 */
function comment_revisions_revert_confirm(&$form_state, $vid) {
  $form['vid'] = array('#type' => 'value', '#value' => $vid);
  $revision = comment_revisions_load_revision($vid);
  return confirm_form($form, t('Are you sure you want to revert to the revision from %revision-date?', array('%revision-date' => format_date($revision->createdon))), 'commentrevision/' . $revision->cid, '', t('Revert'), t('Cancel'));
}

/**
 * Submit revert form.
 */
function comment_revisions_revert_confirm_submit($form, &$form_state) {
  $vid = $form_state['values']['vid'];
  comment_revisions_revert_revision($vid);
  $revision = comment_revisions_load_revision($vid);
  $form_state['redirect'] = 'commentrevision/' . $revision->cid;
}

/**
 * Confirm delete form.
 */
function comment_revisions_delete_confirm(&$form_state, $vid) {
  $revision = comment_revisions_load_revision($vid);
  $current_revision = _comment_revisions_get_current_revision($revision->cid);
  $extra_info = ($current_revision == $revision->vid) ? ' This is the current revision of the comment. Deleting this will revert the comment to the newest revision.' : '';
  $form['revision'] = array('#type' => 'value', '#value' => $revision);
  return confirm_form($form, t('Are you sure you want to delete the revision from %revision-date?' . $extra_info, array('%revision-date' => format_date($revision->createdon))), 'commentrevision/' . $revision->cid, '', t('Delete'), t('Cancel'));
}

/**
 * Submit delete form.
 */
function comment_revisions_delete_confirm_submit($form, &$form_state) {
  $revision = $form_state['values']['revision'];
  $vid = $revision->vid;
  if (comment_revisions_delete_revision($vid)) {
    $cid = $revision->cid;
    $form_state['redirect'] = "commentrevision/$cid";
    drupal_set_message(t('Deleted Comment Revision %cid:%vid from %revision-date', array('%cid' => $cid, '%vid' => $vid, '%revision-date' => format_date($revision->createdon))));
  }
}

